/*
 * Copyright 2019, Adrien Destugues <pulkomandy@pulkomandy.tk>
 * Distributed under terms of the MIT license.
 */


#include <Application.h>
#include <Bitmap.h>
#include <View.h>
#include <Window.h>

#include <assert.h>


class BitmapView: public BView
{
	public:
		BitmapView(BBitmap* bitmap)
			: BView(bitmap->Bounds(), "test view", B_FOLLOW_LEFT_TOP, B_WILL_DRAW)
			, fBitmap(bitmap)
		{
		}

		~BitmapView()
		{
			delete fBitmap;
		}

		void Draw(BRect updateRect)
		{
			DrawBitmap(fBitmap);
		}

	private:
		BBitmap* fBitmap;
};


int
main(void)
{
	BApplication app("application/Haiku-BitmapTest");

	BWindow* window = new BWindow(BRect(10, 10, 100, 100),
		"Bitmap drawing test", B_DOCUMENT_WINDOW, B_QUIT_ON_WINDOW_CLOSE);
	window->Show();

	BBitmap* bitmap = new BBitmap(BRect(0, 0, 24, 24), B_RGBA32, true);

	BView* childOfBitmap = new BView(bitmap->Bounds(), NULL, 0, B_WILL_DRAW);
	bitmap->AddChild(childOfBitmap);
	if (childOfBitmap->LockLooper()) {
		//Uncomment to make FillRect fail
		//childOfBitmap->Invalidate();
		childOfBitmap->SetHighColor(0, 0, 0, 128);
		childOfBitmap->FillRect(childOfBitmap->Bounds());
		childOfBitmap->Invalidate();
		childOfBitmap->UnlockLooper();
	}
	

	BView* view = new BitmapView(bitmap);
	window->AddChild(view);

	app.Run();
	return 0;
}
